@@ -55,9 +55,9 @@ def distance_point_point(a, b):
 
     Parameters
     ----------
-    a : [float, float, float] | :class:`compas.geometry.Point`
+    a : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of point a.
-    b : [float, float, float] | :class:`compas.geometry.Point`
+    b : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of point b.
 
     Returns
@@ -84,9 +84,9 @@ def distance_point_point_xy(a, b):
 
     Parameters
     ----------
-    a : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    a : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a 2D or 3D point (Z will be ignored).
-    b : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    b : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a 2D or 3D point (Z will be ignored).
 
     Returns
@@ -115,9 +115,9 @@ def distance_point_point_sqrd(a, b):
 
     Parameters
     ----------
-    a : [float, float, float] | :class:`compas.geometry.Point`
+    a : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of point a.
-    b : [float, float, float] | :class:`compas.geometry.Point`
+    b : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of point b.
 
     Returns
@@ -144,9 +144,9 @@ def distance_point_point_sqrd_xy(a, b):
 
     Parameters
     ----------
-    a : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    a : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of the first point.
-    b : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    b : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of the second point.
 
     Returns
@@ -175,9 +175,9 @@ def distance_point_line(point, line):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         Point location.
-    line : [point, point] | :class:`compas.geometry.Line`
+    line : [point, point] | :class:`~compas.geometry.Line`
         Line defined by two points.
 
     Returns
@@ -215,9 +215,9 @@ def distance_point_line_xy(point, line):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of the point.
-    line : [point, point] | :class:`compas.geometry.Line`
+    line : [point, point] | :class:`~compas.geometry.Line`
         Line defined by two points.
 
     Returns
@@ -251,9 +251,9 @@ def distance_point_line_sqrd(point, line):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of the point.
-    line : [point, point] | :class:`compas.geometry.Line`
+    line : [point, point] | :class:`~compas.geometry.Line`
         Line defined by two points.
 
     Returns
@@ -285,9 +285,9 @@ def distance_point_line_sqrd_xy(point, line):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a 2D or 3D point (Z will be ignored).
-    line : [point, point] | :class:`compas.geometry.Line`
+    line : [point, point] | :class:`~compas.geometry.Line`
         Line defined by two points.
 
     Returns
@@ -321,9 +321,9 @@ def distance_point_plane(point, plane):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         Point coordinates.
-    plane : [point, vector] | :class:`compas.geometry.Plane`
+    plane : [point, vector] | :class:`~compas.geometry.Plane`
         A point and a vector defining a plane.
 
     Returns
@@ -376,9 +376,9 @@ def distance_point_plane_signed(point, plane):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         Point coordinates.
-    plane : [point, vector] | :class:`compas.geometry.Plane`
+    plane : [point, vector] | :class:`~compas.geometry.Plane`
         A point and a vector defining a plane.
 
     Returns
@@ -433,9 +433,9 @@ def distance_line_line(l1, l2, tol=0.0):
 
     Parameters
     ----------
-    l1 : [point, point] | :class:`compas.geometry.Line`
+    l1 : [point, point] | :class:`~compas.geometry.Line`
         Two points defining a line.
-    l2 : [point, point] | :class:`compas.geometry.Line`
+    l2 : [point, point] | :class:`~compas.geometry.Line`
         Two points defining a line.
 
     Returns
@@ -487,9 +487,9 @@ def sort_points(point, cloud):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         The XYZ coordinates of the base point.
-    cloud : sequence[[float, float, float] | :class:`compas.geometry.Point`]
+    cloud : sequence[[float, float, float] | :class:`~compas.geometry.Point`]
         A sequence locations in three-dimensional space.
 
     Returns
@@ -518,9 +518,9 @@ def sort_points_xy(point, cloud):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a point.
-    cloud : sequence[[float, float] or [float, float, float] | :class:`compas.geometry.Point`]
+    cloud : sequence[[float, float] or [float, float, float] | :class:`~compas.geometry.Point`]
         A list of points represented by their XY(Z) coordinates.
 
     Returns
@@ -548,9 +548,9 @@ def closest_point_in_cloud(point, cloud):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of the base point.
-    cloud : sequence[[float, float, float] | :class:`compas.geometry.Point`]
+    cloud : sequence[[float, float, float] | :class:`~compas.geometry.Point`]
         A sequence locations in three-dimensional space.
 
     Returns
@@ -636,9 +636,9 @@ def closest_point_in_cloud_xy(point, cloud):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a the base point.
-    cloud : sequence[[float, float] or [float, float, float] | :class:`compas.geometry.Point`]
+    cloud : sequence[[float, float] or [float, float, float] | :class:`~compas.geometry.Point`]
         A list of points forming the cloud, with each point represented by its XY(Z) coordinates.
 
     Returns
@@ -665,9 +665,9 @@ def closest_point_on_line(point, line):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates.
-    line : [point, point] | :class:`compas.geometry.Line`
+    line : [point, point] | :class:`~compas.geometry.Line`
         Two points defining the line.
 
     Returns
@@ -696,9 +696,9 @@ def closest_point_on_line_xy(point, line):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a point.
-    line : [point, point] | :class:`compas.geometry.Line`
+    line : [point, point] | :class:`~compas.geometry.Line`
         Two XY(Z) points defining a line.
 
     Returns
@@ -719,9 +719,9 @@ def closest_point_on_segment(point, segment):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates.
-    segment : [point, point] | :class:`compas.geometry.Line`
+    segment : [point, point] | :class:`~compas.geometry.Line`
         Two points defining the segment.
 
     Returns
@@ -751,9 +751,9 @@ def closest_point_on_segment_xy(point, segment):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a point.
-    segment : [point, point] | :class:`compas.geometry.Line`
+    segment : [point, point] | :class:`~compas.geometry.Line`
         Two 2D or 3D points defining the line segment (Z components will be ignored).
 
     Returns
@@ -779,9 +779,9 @@ def closest_point_on_polyline(point, polyline):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of a 2D or 3D point (Z will be ignored).
-    polyline : sequence[point] | :class:`compas.geometry.Polyline`
+    polyline : sequence[point] | :class:`~compas.geometry.Polyline`
         A sequence of XYZ coordinates representing the locations of the corners of a polyline.
         The vertices are assumed to be in order.
 
@@ -805,9 +805,9 @@ def closest_point_on_polyline_xy(point, polyline):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a 2D or 3D point (Z will be ignored).
-    polyline : sequence[point] | :class:`compas.geometry.Polyline`
+    polyline : sequence[point] | :class:`~compas.geometry.Polyline`
         A sequence of XY(Z) coordinates of 2D or 3D points (Z will be ignored)
         representing the locations of the corners of a polyline.
         The vertices are assumed to be in order.
@@ -831,9 +831,9 @@ def closest_point_on_polygon_xy(point, polygon):
 
     Parameters
     ----------
-    point : [float, float] or [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float] or [float, float, float] | :class:`~compas.geometry.Point`
         XY(Z) coordinates of a 2D or 3D point (Z will be ignored).
-    polygon : sequence[point] | :class:`compas.geometry.Polygon`
+    polygon : sequence[point] | :class:`~compas.geometry.Polygon`
         A sequence of XY(Z) coordinates of 2D or 3D points
         (Z will be ignored) representing the locations of the corners of a polygon.
         The vertices are assumed to be in order. The polygon is assumed to be closed:
@@ -858,9 +858,9 @@ def closest_point_on_plane(point, plane):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of point.
-    plane : [point, vector] | :class:`compas.geometry.Plane`
+    plane : [point, vector] | :class:`~compas.geometry.Plane`
         The base point and normal defining the plane.
 
     Returns
@@ -901,9 +901,9 @@ def closest_line_to_point(point, lines):
 
     Parameters
     ----------
-    point : [float, float, float] | :class:`compas.geometry.Point`
+    point : [float, float, float] | :class:`~compas.geometry.Point`
         XYZ coordinates of point.
-    lines : sequence[[point, point] | :class:`compas.geometry.Line`].
+    lines : sequence[[point, point] | :class:`~compas.geometry.Line`].
         The lines to be checked for distance.
 
     Returns
